==> qt-creator-opensource-src-4.10.2.zip: qt-creator-opensource-src-4.10.2/src/plugins/autotest/testeditormark.cpp <==
/****************************************************************************
**
** Copyright (C) 2018 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "testeditormark.h"
#include "testresultspane.h"

namespace Autotest {
namespace Internal {

TestEditorMark::TestEditorMark(QPersistentModelIndex item, const Utils::FilePath &file, int line)
    : TextEditor::TextMark(file, line, Core::Id(Constants::TASK_MARK_ID)),
      m_item(item)
{
}

void TestEditorMark::clicked()
{
    auto instance = TestResultsPane::instance();
    instance->showTestResult(m_item);
}

} // namespace Internal
} // namespace Autotest

==> qt-creator-opensource-src-4.13.0.zip: qt-creator-opensource-src-4.13.0/src/plugins/autotest/testeditormark.cpp <==
/****************************************************************************
**
** Copyright (C) 2018 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#include "testeditormark.h"
#include "testresultspane.h"

namespace Autotest {
namespace Internal {

TestEditorMark::TestEditorMark(QPersistentModelIndex item, const Utils::FilePath &file, int line)
    : TextEditor::TextMark(file, line, Utils::Id(Constants::TASK_MARK_ID)),
      m_item(item)
{
}

void TestEditorMark::clicked()
{
    auto instance = TestResultsPane::instance();
    instance->showTestResult(m_item);
}

} // namespace Internal
} // namespace Autotest
